Repeat

Struct Repeat 

pub struct Repeat<C>(pub C);
A combinator to repeatedly parse/serialize the inner combinator C until the end of the buffer.

If the inner combinator fails before the end of the buffer, Repeat fails

Tuple Fields

0: C

Implementations

Source

impl<'x, C: View> Repeat<C>

pub exec fn new(c: C) -> o : Self

requires
c@.is_productive(),
ensures
o == Self(c),

Constructs a new Repeat combinator, only if the inner combinator is productive.